All of lore.kernel.org
 help / color / mirror / Atom feed
From: Ingo Molnar <mingo@kernel.org>
To: linux-kernel@vger.kernel.org
Cc: Dietmar Eggemann <dietmar.eggemann@arm.com>,
	Linus Torvalds <torvalds@linux-foundation.org>,
	Peter Zijlstra <peterz@infradead.org>,
	Shrikanth Hegde <sshegde@linux.ibm.com>,
	Valentin Schneider <vschneid@redhat.com>,
	Vincent Guittot <vincent.guittot@linaro.org>
Subject: [PATCH 07/13] sched/balancing: Rename find_src_rq() => sched_balance_find_src_rq()
Date: Fri,  8 Mar 2024 12:18:13 +0100	[thread overview]
Message-ID: <20240308111819.1101550-8-mingo@kernel.org> (raw)
In-Reply-To: <20240308111819.1101550-1-mingo@kernel.org>

Standardize scheduler load-balancing function names on the
sched_balance_() prefix.

Signed-off-by: Ingo Molnar <mingo@kernel.org>
Cc: Dietmar Eggemann <dietmar.eggemann@arm.com>
Cc: Linus Torvalds <torvalds@linux-foundation.org>
Cc: Peter Zijlstra <peterz@infradead.org>
Cc: Shrikanth Hegde <sshegde@linux.ibm.com>
Cc: Valentin Schneider <vschneid@redhat.com>
Cc: Vincent Guittot <vincent.guittot@linaro.org>
---
 kernel/sched/fair.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/kernel/sched/fair.c b/kernel/sched/fair.c
index e600cac7806d..1cd9a18b35e0 100644
--- a/kernel/sched/fair.c
+++ b/kernel/sched/fair.c
@@ -10959,9 +10959,9 @@ static struct sched_group *find_busiest_group(struct lb_env *env)
 }
 
 /*
  * find_src_rq - find the busiest runqueue among the CPUs in the group.
  */
-static struct rq *find_src_rq(struct lb_env *env,
+static struct rq *sched_balance_find_src_rq(struct lb_env *env,
 				     struct sched_group *group)
 {
 	struct rq *busiest = NULL, *rq;
@@ -11280,7 +11280,7 @@ static int sched_balance_rq(int this_cpu, struct rq *this_rq,
 		goto out_balanced;
 	}
 
-	busiest = find_src_rq(&env, group);
+	busiest = sched_balance_find_src_rq(&env, group);
 	if (!busiest) {
 		schedstat_inc(sd->lb_nobusyq[idle]);
 		goto out_balanced;
@@ -10959,9 +10959,9 @@ static struct sched_group *find_busiest_group(struct lb_env *env)
 
 /*
- * find_src_rq - find the busiest runqueue among the CPUs in the group.
+ * sched_balance_find_src_rq - find the busiest runqueue among the CPUs in the group.
  */
-- 
2.40.1


  parent reply	other threads:[~2024-03-08 11:18 UTC|newest]

Thread overview: 33+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2024-03-08 11:18 [PATCH -v1 00/13] sched/balancing: Standardize the naming of scheduler load-balancing functions Ingo Molnar
2024-03-08 11:18 ` [PATCH 01/13] sched/balancing: Rename run_rebalance_domains() => sched_balance_softirq() Ingo Molnar
2024-03-12 12:00   ` [tip: sched/core] " tip-bot2 for Ingo Molnar
2024-03-08 11:18 ` [PATCH 02/13] sched/balancing: Rename scheduler_tick() => sched_tick() Ingo Molnar
2024-03-12 12:00   ` [tip: sched/core] " tip-bot2 for Ingo Molnar
2024-03-08 11:18 ` [PATCH 03/13] sched/balancing: Rename trigger_load_balance() => sched_balance_trigger() Ingo Molnar
2024-03-12 12:00   ` [tip: sched/core] " tip-bot2 for Ingo Molnar
2024-03-08 11:18 ` [PATCH 04/13] sched/balancing: Rename rebalance_domains() => sched_balance_domains() Ingo Molnar
2024-03-12 12:00   ` [tip: sched/core] " tip-bot2 for Ingo Molnar
2024-03-08 11:18 ` [PATCH 05/13] sched/balancing: Rename load_balance() => sched_balance_rq() Ingo Molnar
2024-03-11  8:17   ` Shrikanth Hegde
2024-03-12 10:27     ` Ingo Molnar
2024-03-12 12:00   ` [tip: sched/core] " tip-bot2 for Ingo Molnar
2024-03-08 11:18 ` [PATCH 06/13] sched/balancing: Rename find_busiest_queue() => find_src_rq() Ingo Molnar
2024-03-12 12:00   ` [tip: sched/core] sched/balancing: Rename find_busiest_queue() => sched_balance_find_src_rq() tip-bot2 for Ingo Molnar
2024-03-08 11:18 ` Ingo Molnar [this message]
2024-03-08 13:51   ` [PATCH 07/13] sched/balancing: Rename find_src_rq() " Vincent Guittot
2024-03-08 17:49     ` Ingo Molnar
2024-03-08 11:18 ` [PATCH 08/13] sched/balancing: Rename find_busiest_group() => sched_balance_find_src_group() Ingo Molnar
2024-03-12 12:00   ` [tip: sched/core] " tip-bot2 for Ingo Molnar
2024-03-08 11:18 ` [PATCH 09/13] sched/balancing: Rename update_blocked_averages() => sched_balance_update_blocked_averages() Ingo Molnar
2024-03-11  6:42   ` Honglei Wang
2024-03-12 10:36     ` Ingo Molnar
2024-03-12 12:00   ` [tip: sched/core] " tip-bot2 for Ingo Molnar
2024-03-08 11:18 ` [PATCH 10/13] sched/balancing: Rename newidle_balance() => sched_balance_newidle() Ingo Molnar
2024-03-12 12:00   ` [tip: sched/core] " tip-bot2 for Ingo Molnar
2024-03-08 11:18 ` [PATCH 11/13] sched/balancing: Rename find_idlest_group_cpu() => sched_balance_find_dst_group_cpu() Ingo Molnar
2024-03-12 12:00   ` [tip: sched/core] " tip-bot2 for Ingo Molnar
2024-03-08 11:18 ` [PATCH 12/13] sched/balancing: Rename find_idlest_group() => sched_balance_find_dst_group() Ingo Molnar
2024-03-12 12:00   ` [tip: sched/core] " tip-bot2 for Ingo Molnar
2024-03-08 11:18 ` [PATCH 13/13] sched/balancing: Rename find_idlest_cpu() => sched_balance_find_dst_cpu() Ingo Molnar
2024-03-12 12:00   ` [tip: sched/core] " tip-bot2 for Ingo Molnar
2024-03-08 11:25 ` [PATCH -v1 00/13] sched/balancing: Standardize the naming of scheduler load-balancing functions Ingo Molnar

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20240308111819.1101550-8-mingo@kernel.org \
    --to=mingo@kernel.org \
    --cc=dietmar.eggemann@arm.com \
    --cc=linux-kernel@vger.kernel.org \
    --cc=peterz@infradead.org \
    --cc=sshegde@linux.ibm.com \
    --cc=torvalds@linux-foundation.org \
    --cc=vincent.guittot@linaro.org \
    --cc=vschneid@redhat.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.